aboutsummaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
authorMorris Jobke <hey@morrisjobke.de>2017-03-20 21:29:55 -0600
committerMorris Jobke <hey@morrisjobke.de>2017-04-04 15:56:50 -0500
commit0fcb37adcb08e8a74d712ff8a6146f91fa14d7a9 (patch)
tree7d6c6c93b0180d670b859d6f861d4594bc849d96 /lib
parent695a17804ed261980e9c3c20a588c1f3a3a3507f (diff)
downloadnextcloud-server-0fcb37adcb08e8a74d712ff8a6146f91fa14d7a9.tar.gz
nextcloud-server-0fcb37adcb08e8a74d712ff8a6146f91fa14d7a9.zip
OC_ -> NC_
Signed-off-by: Morris Jobke <hey@morrisjobke.de>
Diffstat (limited to 'lib')
-rw-r--r--lib/private/Config.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/private/Config.php b/lib/private/Config.php
index 28d8c560c5d..79742026660 100644
--- a/lib/private/Config.php
+++ b/lib/private/Config.php
@@ -40,7 +40,7 @@ namespace OC;
*/
class Config {
- const ENV_PREFIX = 'OC_';
+ const ENV_PREFIX = 'NC_';
/** @var array Associative array ($key => $value) */
protected $cache = array();
@@ -76,7 +76,7 @@ class Config {
/**
* Returns a config value
*
* gets its value from an `OC_` prefixed environment variable
* if it doesn't exist from config.php
* if this doesn't exist either, it will return the given `$default`
*
@@ -76,7 +76,7 @@ class Config {
* Returns a config value
*
- * gets its value from an `OC_` prefixed environment variable
+ * gets its value from an `NC_` prefixed environment variable
* if it doesn't exist from config.php
* if this doesn't exist either, it will return the given `$default`